spannertools.Beam
=================

.. abjad-lineage:: abjad.tools.spannertools.Beam.Beam

.. autoclass:: abjad.tools.spannertools.Beam.Beam

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.Beam.Beam.append
      ~abjad.tools.spannertools.Beam.Beam.append_left
      ~abjad.tools.spannertools.Beam.Beam.components
      ~abjad.tools.spannertools.Beam.Beam.detach
      ~abjad.tools.spannertools.Beam.Beam.direction
      ~abjad.tools.spannertools.Beam.Beam.extend
      ~abjad.tools.spannertools.Beam.Beam.extend_left
      ~abjad.tools.spannertools.Beam.Beam.fracture
      ~abjad.tools.spannertools.Beam.Beam.fuse
      ~abjad.tools.spannertools.Beam.Beam.get_duration
      ~abjad.tools.spannertools.Beam.Beam.get_timespan
      ~abjad.tools.spannertools.Beam.Beam.index
      ~abjad.tools.spannertools.Beam.Beam.is_beamable_component
      ~abjad.tools.spannertools.Beam.Beam.leaves
      ~abjad.tools.spannertools.Beam.Beam.pop
      ~abjad.tools.spannertools.Beam.Beam.pop_left
      ~abjad.tools.spannertools.Beam.Beam.__contains__
      ~abjad.tools.spannertools.Beam.Beam.__copy__
      ~abjad.tools.spannertools.Beam.Beam.__eq__
      ~abjad.tools.spannertools.Beam.Beam.__format__
      ~abjad.tools.spannertools.Beam.Beam.__getitem__
      ~abjad.tools.spannertools.Beam.Beam.__len__
      ~abjad.tools.spannertools.Beam.Beam.__lt__
      ~abjad.tools.spannertools.Beam.Beam.__ne__
      ~abjad.tools.spannertools.Beam.Beam.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.Beam.Beam.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.Beam.Beam.leaves
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.spannertools.Beam.Beam.direction
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.Beam.Beam.append
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.index
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.pop_left
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.spannertools.Beam.Beam.is_beamable_component
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.Beam.Beam.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.Beam.Beam.__repr__
   :noindex:
